mysql.exceptions.base.Error

Package mysql :: Package exceptions :: Module base :: Class Error |
[hide private]
[frames] | no frames]

# Class Error

source code

    exceptions.Exception --+
                           |
                          Error

Known Subclasses:
  internal.Affected_Rows_Unavailable, internal.Connected_Error, internal.Data_Truncated, internal.No_Insert_ID_Error, internal.No_More_Results, internal.No_More_Rows, internal.No_Statement_Info_Error, internal.Not_Connected_Error, internal.Result_Closed_Error, internal.Result_Unbuffered_Error, internal.Statement_Closed_Error, MySQL_Error

Base class for all MySQL exceptions.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`